==> modoboa-pdfcredentials-1.1.0.tar.gz: modoboa-pdfcredentials-1.1.0/modoboa_pdfcredentials/lib.py <==
"""Internal library."""

from io import BytesIO
import os
import random
import struct

from Crypto.Cipher import AES

from django.conf import settings
from django.utils.translation import ugettext as _

from modoboa.lib.exceptions import InternalError
from modoboa.parameters import tools as param_tools


def init_storage_dir():
    """Create the directory whare documents will be stored."""
    storage_dir = param_tools.get_global_parameter("storage_dir")
    if os.path.exists(storage_dir):
        return
    try:
        os.mkdir(storage_dir)
    except (OSError, IOError) as inst:
        raise InternalError(
            _("Failed to create the directory that will contain "
              "PDF documents (%s)") % inst
        )


def get_creds_filename(account):
    """Return the full path of a document."""
    storage_dir = param_tools.get_global_parameter("storage_dir")
    return os.path.join(storage_dir, account.username + ".pdf")


def delete_credentials(account):
    """Try to delete a local file."""
    fname = get_creds_filename(account)
    if not os.path.exists(fname):
        return
    try:
        os.remove(fname)
    except OSError:
        pass


def crypt_and_save_to_file(content, filename, length, chunksize=64*1024):
    """Crypt content and save it to a file."""
    key = param_tools.get_global_parameter("secret_key", app="core")
    iv = "".join(chr(random.randint(0, 0xFF)) for i in range(16))
    encryptor = AES.new(key, AES.MODE_CBC, iv)
    with open(filename, 'wb') as fp:
        fp.write(struct.pack('<Q', length))
        fp.write(iv)
        while True:
            chunk = content.read(chunksize)
            if not len(chunk):
                break
            elif len(chunk) % 16:
                chunk += ' ' * (16 - len(chunk) % 16)
            fp.write(encryptor.encrypt(chunk))


def decrypt_file(filename, chunksize=24*1024):
    """Decrypt the content of a file and return it."""
    buff = BytesIO()
    key = param_tools.get_global_parameter("secret_key", app="core")
    with open(filename, 'rb') as fp:
        origsize = struct.unpack('<Q', fp.read(struct.calcsize('Q')))[0]
        iv = fp.read(16)
        decryptor = AES.new(key, AES.MODE_CBC, iv)
        while True:
            chunk = fp.read(chunksize)
            if not len(chunk):
                break
            buff.write(decryptor.decrypt(chunk))
        buff.truncate(origsize)
    return buff.getvalue()


def get_document_logo():
    """Retrieve path to logo."""
    try:
        logo = settings.MODOBOA_CUSTOM_LOGO
        logo = os.path.join(settings.MEDIA_ROOT, os.path.basename(logo))
    except AttributeError:
        logo = os.path.join(settings.STATIC_ROOT, "css/modoboa.png")
    finally:
        return logo

==> modoboa-pdfcredentials-1.1.2.tar.gz: modoboa-pdfcredentials-1.1.2/modoboa_pdfcredentials/lib.py <==
"""Internal library."""

from io import BytesIO
import os
import random
import struct

from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
from cryptography.hazmat.backends import default_backend

from django.conf import settings
from django.utils.encoding import force_bytes
from django.utils.translation import ugettext as _

from modoboa.lib.exceptions import InternalError
from modoboa.parameters import tools as param_tools


def init_storage_dir():
    """Create the directory whare documents will be stored."""
    storage_dir = param_tools.get_global_parameter("storage_dir")
    if os.path.exists(storage_dir):
        return
    try:
        os.mkdir(storage_dir)
    except (OSError, IOError) as inst:
        raise InternalError(
            _("Failed to create the directory that will contain "
              "PDF documents (%s)") % inst
        )


def get_creds_filename(account):
    """Return the full path of a document."""
    storage_dir = param_tools.get_global_parameter("storage_dir")
    return os.path.join(storage_dir, account.username + ".pdf")


def delete_credentials(account):
    """Try to delete a local file."""
    fname = get_creds_filename(account)
    if not os.path.exists(fname):
        return
    try:
        os.remove(fname)
    except OSError:
        pass


def _get_cipher(iv):
    """Return ready-to-user Cipher."""
    key = param_tools.get_global_parameter("secret_key", app="core")
    backend = default_backend()
    return Cipher(
        algorithms.AES(force_bytes(key)),
        modes.CBC(force_bytes(iv)),
        backend=backend
    )


def crypt_and_save_to_file(content, filename, length, chunksize=64*1024):
    """Crypt content and save it to a file."""
    iv = "".join(chr(random.randint(0, 0xFF)) for i in range(16))
    cipher = _get_cipher(iv)
    encryptor = cipher.encryptor()
    with open(filename, 'wb') as fp:
        fp.write(struct.pack('<Q', length))
        fp.write(iv)
        while True:
            chunk = content.read(chunksize)
            if not len(chunk):
                break
            elif len(chunk) % 16:
                chunk += ' ' * (16 - len(chunk) % 16)
            fp.write(
                encryptor.update(force_bytes(chunk)) + encryptor.finalize())


def decrypt_file(filename, chunksize=24*1024):
    """Decrypt the content of a file and return it."""
    buff = BytesIO()
    with open(filename, 'rb') as fp:
        origsize = struct.unpack('<Q', fp.read(struct.calcsize('Q')))[0]
        iv = fp.read(16)
        cipher = _get_cipher(iv)
        decryptor = cipher.decryptor()
        while True:
            chunk = fp.read(chunksize)
            if not len(chunk):
                break
            buff.write(decryptor.update(chunk))
        buff.write(decryptor.finalize())
        buff.truncate(origsize)
    return buff.getvalue()


def get_document_logo():
    """Retrieve path to logo."""
    try:
        logo = settings.MODOBOA_CUSTOM_LOGO
        logo = os.path.join(settings.MEDIA_ROOT, os.path.basename(logo))
    except AttributeError:
        logo = os.path.join(settings.STATIC_ROOT, "css/modoboa.png")
    finally:
        return logo
